Computes the Cholesky decomposition of a symmetric positive-definite matrix. Dimensions before the last two are batch dimensions.
Arguments
- operand
(
tensorish)
Tensorish value of data type floating-point with at least 2 dimensions. The last two dimensions must be equal (square matrix); any leading dimensions are batch dimensions.- lower
(
logical(1))
IfTRUE, compute the lower triangular factorLsuch thatoperand = L %*% t(L). IfFALSE, compute the upper triangular factorUsuch thatoperand = t(U) %*% U.
Value
tensorish
Has the same shape and data type as the input.
The values in the triangle not specified by lower are implementation-defined.
It is ambiguous if the input is ambiguous.
StableHLO
Lowers to stablehlo::hlo_cholesky().
References
Murray, Iain (2016). “Differentiation of the Cholesky decomposition.” arXiv preprint arXiv:1602.07527.
Walter, Sebastian (2012). Structured higher-order algorithmic differentiation in the forward and reverse mode with application in optimum experimental design. Ph.D. thesis, Mathematisch-Naturwissenschaftliche Fakult"at II.